@@ -43,8 +43,6 @@
 #include "pk-spawn.h"
 #include "pk-shared.h"
 
-#include "pk-sysdep.h"
-
 static void     pk_spawn_finalize	(GObject       *object);
 
 #define PK_SPAWN_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PK_TYPE_SPAWN, PkSpawnPrivate))
@@ -90,9 +88,6 @@ static guint signals [SIGNAL_LAST] = { 0 };
 
 G_DEFINE_TYPE (PkSpawn, pk_spawn, G_TYPE_OBJECT)
 
-/**
- * pk_spawn_read_fd_into_buffer:
- **/
 static gboolean
 pk_spawn_read_fd_into_buffer (gint fd, GString *string)
 {
@@ -108,16 +103,13 @@ pk_spawn_read_fd_into_buffer (gint fd, GString *string)
 	return TRUE;
 }
 
-/**
- * pk_spawn_emit_whole_lines:
- **/
 static gboolean
 pk_spawn_emit_whole_lines (PkSpawn *spawn, GString *string)
 {
 	guint i;
 	guint size;
-	gchar **lines;
 	guint bytes_processed;
+	g_auto(GStrv) lines = NULL;
 
 	/* if nothing then don't emit */
 	if (pk_strzero (string->str))
@@ -133,7 +125,7 @@ pk_spawn_emit_whole_lines (PkSpawn *spawn, GString *string)
 
 	bytes_processed = 0;
 	/* we only emit n-1 strings */
-	for (i=0; i<(size-1); i++) {
+	for (i = 0; i < (size-1); i++) {
 		g_signal_emit (spawn, signals [SIGNAL_STDOUT], 0, lines[i]);
 		/* ITS4: ignore, g_strsplit always NULL terminates */
 		bytes_processed += strlen (lines[i]) + 1;
@@ -141,14 +133,9 @@ pk_spawn_emit_whole_lines (PkSpawn *spawn, GString *string)
 
 	/* remove the text we've processed */
 	g_string_erase (string, 0, bytes_processed);
-
-	g_strfreev (lines);
 	return TRUE;
 }
 
-/**
- * pk_spawn_exit_type_enum_to_string:
- **/
 static const gchar *
 pk_spawn_exit_type_enum_to_string (PkSpawnExitType type)
 {
@@ -167,9 +154,6 @@ pk_spawn_exit_type_enum_to_string (PkSpawnExitType type)
 	return "unknown";
 }
 
-/**
- * pk_spawn_check_child:
- **/
 static gboolean
 pk_spawn_check_child (PkSpawn *spawn)
 {
@@ -292,9 +276,6 @@ pk_spawn_check_child (PkSpawn *spawn)
 	return FALSE;
 }
 
-/**
- * pk_spawn_sigkill_cb:
- **/
 static gboolean
 pk_spawn_sigkill_cb (PkSpawn *spawn)
 {
@@ -396,23 +377,20 @@ pk_spawn_send_stdin (PkSpawn *spawn, const gchar *command)
 {
 	gint wrote;
 	gint length;
-	gchar *buffer = NULL;
-	gboolean ret = TRUE;
+	g_autofree gchar *buffer = NULL;
 
 	g_return_val_if_fail (PK_IS_SPAWN (spawn), FALSE);
 
 	/* check if process has already gone */
 	if (spawn->priv->finished) {
 		g_debug ("already finished, ignoring");
-		ret = FALSE;
-		goto out;
+		return FALSE;
 	}
 
 	/* is there a process running? */
 	if (spawn->priv->child_pid == -1) {
 		g_debug ("no child pid");
-		ret = FALSE;
-		goto out;
+		return FALSE;
 	}
 
 	/* buffer always has to have trailing newline */
@@ -425,12 +403,11 @@ pk_spawn_send_stdin (PkSpawn *spawn, const gchar *command)
 	/* write to the waiting process */
 	wrote = write (spawn->priv->stdin_fd, buffer, length);
 	if (wrote != length) {
-		g_warning ("wrote %i/%i bytes on fd %i (%s)", wrote, length, spawn->priv->stdin_fd, strerror (errno));
-		ret = FALSE;
+		g_warning ("wrote %i/%i bytes on fd %i (%s)", wrote, length,
+			   spawn->priv->stdin_fd, strerror (errno));
+		return FALSE;
 	}
-out:
-	g_free (buffer);
-	return ret;
+	return TRUE;
 }
 
 /**
@@ -482,9 +459,6 @@ out:
 	return ret;
 }
 
-/**
- * pk_strvequal:
- **/
 static gboolean
 pk_strvequal (gchar **id1, gchar **id2)
 {
@@ -507,7 +481,7 @@ pk_strvequal (gchar **id1, gchar **id2)
 		return FALSE;
 
 	/* text equal each one */
-	for (i=0; i<length1; i++) {
+	for (i = 0; i < length1; i++) {
 		if (g_strcmp0 (id1[i], id2[i]) != 0)
 			return FALSE;
 	}
@@ -526,24 +500,24 @@ pk_spawn_argv (PkSpawn *spawn, gchar **argv, gchar **envp,
 	       PkSpawnArgvFlags flags, GError **error)
 {
 	gboolean ret = TRUE;
-	GError *error_local = NULL;
 	guint i;
 	guint len;
-	gint nice_value;
-	gchar *command;
-	const gchar *key;
+#if HAVE_SETPRIORITY
+	gint nice_value = 0;
+#endif
 	gint rc;
+	g_autoptr(GError) error_local = NULL;
 
 	g_return_val_if_fail (PK_IS_SPAWN (spawn), FALSE);
 	g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
 	g_return_val_if_fail (argv != NULL, FALSE);
 
 	len = g_strv_length (argv);
-	for (i=0; i<len; i++)
+	for (i = 0; i < len; i++)
 		g_debug ("argv[%i] '%s'", i, argv[i]);
 	if (envp != NULL) {
 		len = g_strv_length (envp);
-		for (i=0; i<len; i++)
+		for (i = 0; i < len; i++)
 			g_debug ("envp[%i] '%s'", i, envp[i]);
 	}
 
@@ -567,12 +541,11 @@ pk_spawn_argv (PkSpawn *spawn, gchar **argv, gchar **envp,
 			g_debug ("not re-using instance due to policy");
 		} else {
 			/* join with tabs, as spaces could be in file name */
-			command = g_strjoinv ("\t", &argv[1]);
+			g_autofree gchar *command = g_strjoinv ("\t", &argv[1]);
 
 			/* reuse instance */
 			g_debug ("reusing instance");
 			ret = pk_spawn_send_stdin (spawn, command);
-			g_free (command);
 			if (ret)
 				goto out;
 
@@ -608,18 +581,14 @@ pk_spawn_argv (PkSpawn *spawn, gchar **argv, gchar **envp,
 	/* we failed to invoke the helper */
 	if (!ret) {
 		g_set_error (error, 1, 0, "failed to spawn %s: %s", argv[0], error_local->message);
-		g_error_free (error_local);
 		goto out;
 	}
 
-	/* get the nice value and ensure we are in the valid range */
-	key = "BackendSpawnNiceValue";
-	if (spawn->priv->background)
-		key = "BackendSpawnNiceValueBackground";
-	nice_value = g_key_file_get_integer (spawn->priv->conf, "Daemon", key, NULL);
-	nice_value = CLAMP(nice_value, -20, 19);
-
 #if HAVE_SETPRIORITY
+	/* get the nice value and ensure we are in the valid range */
+	if (spawn->priv->background)
+		nice_value = 10;
+
 	/* don't completely bog the system down */
 	if (nice_value != 0) {
 		g_debug ("renice to %i", nice_value);
@@ -668,9 +637,6 @@ out:
 	return ret;
 }
 
-/**
- * pk_spawn_get_property:
- **/
 static void
 pk_spawn_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
 {
@@ -690,9 +656,6 @@ pk_spawn_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec
 	}
 }
 
-/**
- * pk_spawn_set_property:
- **/
 static void
 pk_spawn_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
@@ -712,10 +675,6 @@ pk_spawn_set_property (GObject *object, guint prop_id, const GValue *value, GPar
 	}
 }
 
-/**
- * pk_spawn_class_init:
- * @klass: The PkSpawnClass
- **/
 static void
 pk_spawn_class_init (PkSpawnClass *klass)
 {
@@ -731,7 +690,7 @@ pk_spawn_class_init (PkSpawnClass *klass)
 	 */
 	pspec = g_param_spec_boolean ("background", NULL, NULL,
 				      FALSE,
-				      G_PARAM_READWRITE);
+				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_BACKGROUND, pspec);
 
 	/**
@@ -742,7 +701,7 @@ pk_spawn_class_init (PkSpawnClass *klass)
 	 */
 	pspec = g_param_spec_boolean ("allow-sigkill", NULL, NULL,
 				      FALSE,
-				      G_PARAM_READWRITE);
+				      G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 	g_object_class_install_property (object_class, PROP_ALLOW_SIGKILL, pspec);
 
 	signals [SIGNAL_EXIT] =
@@ -764,10 +723,6 @@ pk_spawn_class_init (PkSpawnClass *klass)
 	g_type_class_add_private (klass, sizeof (PkSpawnPrivate));
 }
 
-/**
- * pk_spawn_init:
- * @spawn: This class instance
- **/
 static void
 pk_spawn_init (PkSpawn *spawn)
 {
@@ -792,10 +747,6 @@ pk_spawn_init (PkSpawn *spawn)
 	spawn->priv->stderr_buf = g_string_new ("");
 }
 
-/**
- * pk_spawn_finalize:
- * @object: The object to finalize
- **/
 static void
 pk_spawn_finalize (GObject *object)
 {
@@ -839,11 +790,6 @@ pk_spawn_finalize (GObject *object)
 	G_OBJECT_CLASS (pk_spawn_parent_class)->finalize (object);
 }
 
-/**
- * pk_spawn_new:
- *
- * Return value: a new PkSpawn object.
- **/
 PkSpawn *
 pk_spawn_new (GKeyFile *conf)
 {
